@@ -213,9 +213,7 @@ class TamingDecoder(ImageGenerator):
                 for the CLIP embeddings. Defaults to None.
             generation_cb (function, optional): if provided, the 
                 function is executed for every optimization step. The
-                inputs of this function will be the generated image
-                from the VQGAN (Nx3xHxW) and the logits used to 
-                generate it (Nx256xDxD) and the optimization step.
+                inputs of this function will be:  loss, step, x_rec, z_logits and step
             init_embed (torh.Tensor, optional): initial embedding 
                 From where to start the generation. Defaults to None.
 
@@ -313,10 +311,10 @@ class TamingDecoder(ImageGenerator):
 
             if generation_cb is not None:
                 generation_cb(
-                    x_rec=x_rec,
                     loss=loss,
-                    z_logits=z_logits,
                     step=step,
+                    x_rec=x_rec,
+                    z_logits=z_logits,
                 )
 
             torch.cuda.empty_cache()
@@ -484,11 +482,10 @@ if __name__ == '__main__':
         init_latent = torch.load(init_latent_path).to('cuda')
     else:
 
-        def save_img_cb(
-            x_rec,
-            _z_logits,
-            step,
-        ):
+        def save_img_cb(**kwargs, ):
+            step = kwargs["step"]
+            x_rec = kwargs["x_rec"]
+
             x_rec_img = torchvision.transforms.ToPILImage(mode='RGB')(x_rec[0])
             x_rec_img.save(f"{step}.jpg")
 
@@ -506,6 +503,7 @@ if __name__ == '__main__':
 
         init_latent = z_logits_list[-1]
         torch.save(init_latent, f'{prompt}_logits.pt')
+
     gen_img_list, z_logits_list = taming_decoder.zoom(
         prompt,
         init_latent=init_latent,
